@@ -665,12 +665,12 @@ static gboolean on_button_release_event(GtkWidget* widget, GdkEventButton* event
 }
 
 static void configured_subscribe(MicrofeedSubscriber* subscriber, const char* publisher, void* user_data) {
-	microfeed_subscriber_subscribe_feed(subscriber, publisher, MICROFEED_FEED_URI_IMAGES, &images_callbacks, NULL, user_data);
-	microfeed_subscriber_subscribe_feed(subscriber, publisher, MICROFEED_FEED_URI_OVERVIEW, &overview_callbacks, feed_subscribed, user_data);
+	microfeed_subscriber_subscribe_feed(subscriber, publisher, MICROFEED_FEED_URI_IMAGES, &images_callbacks, user_data, NULL, NULL);
+	microfeed_subscriber_subscribe_feed(subscriber, publisher, MICROFEED_FEED_URI_OVERVIEW, &overview_callbacks, user_data, feed_subscribed, user_data);
 }
-	
-static void configured_unsubscribe(MicrofeedSubscriber* subscriber, const char* publisher, const char* uri, void* user_data) {
-	microfeed_subscriber_unsubscribe_feed(subscriber, publisher, uri, NULL, NULL);
+
+static void configured_unsubscribe(MicrofeedSubscriber* subscriber, const char* publisher, const char* uri, MicrofeedSubscriberCallbacks* callbacks, void* callbacks_user_data, void* user_data) {
+	microfeed_subscriber_unsubscribe_feed(subscriber, publisher, uri, callbacks, callbacks_user_data, NULL, NULL);
 }
 
 static void on_child_exit(GPid pid, gint status, gpointer user_data) {
@@ -769,7 +769,7 @@ static void mauku_widget_init(MaukuWidget* mauku_widget) {
 	dbus_connection_setup_with_g_main(mauku_widget->priv->connection_system, NULL);
 	mauku_widget->priv->connection_session = hd_home_plugin_item_get_dbus_connection(HD_HOME_PLUGIN_ITEM(mauku_widget), DBUS_BUS_SESSION, &error);
 	dbus_connection_setup_with_g_main(mauku_widget->priv->connection_session, NULL);
-	mauku_widget->priv->subscriber = microfeed_subscriber_new(SUBSCRIBER_ID, "/com/innologies/mauku_widget", mauku_widget->priv->connection_session);
+	mauku_widget->priv->subscriber = microfeed_subscriber_new(SUBSCRIBER_ID, mauku_widget->priv->connection_session);
 	microfeed_subscriber_handle_configured_subscriptions(mauku_widget->priv->subscriber, configured_subscribe, configured_unsubscribe, mauku_widget);
 }
 
